package org.aohe;

import lombok.extern.slf4j.Slf4j;
import org.aohe.core.sane.utils.SaneSessionUtils;
import org.aohe.core.swing.MainWindow;
import org.aohe.core.utils.CommandUtils;
import org.aohe.core.utils.SystemUtils;
import org.aohe.core.web.SocketFactory;
import com.formdev.flatlaf.FlatLightLaf;

import javax.swing.*;

@Slf4j
public class Main {

    public static void main(String[] args) {
        log.info(" 当前系统类型： {}", SystemUtils.getOsName());
        try {
            //设置窗口主题
            //FlatLightLaf.setup();
            UIManager.setLookAndFeel(new FlatLightLaf());
        } catch (UnsupportedLookAndFeelException e) {
            throw new RuntimeException(e);
        }
        //初始化其他资源
        init();
        SwingUtilities.invokeLater(() -> new MainWindow().setVisible(true));

    }

    public static void init(){
        log.info("程序初始化开始...");
        CommandUtils.initSanedSocket();
        stopGracefully();
        log.info("Hook注册成功...");
    }


    public static void stopGracefully() {
        log.info("优雅退出Hook注册");
        //优雅退出，在程序停止时，销毁关键资源占用
        Runtime.getRuntime().addShutdownHook(new Thread(() -> {
            log.info("开始资源释放");
            //释放sane资源
            SaneSessionUtils.resource();
            SocketFactory.stop();
            log.info("socket 服务已关闭 ");
        }));
    }
}